#ifndef __UTYPES_H__
#define __UTYPES_H__

#include <stdint.h>

#define uint8   uint8_t
#define int8    int8_t
#define uint16  uint16_t
#define int16   int16_t
#define uint32  uint32_t
#define int32   int32_t

#define BOOLEAN uint8_t
#define INTEGER8 int8_t
#define INTEGER16 int16_t
#define INTEGER32 int32_t
#define UNSIGNED8 uint8_t
#define UNSIGNED16 uint16_t
#define UNSIGNED32 uint32_t
#define REAL32 float
#define INTEGER24 int32_t
#define UNSIGNED24 uint32_t
#define INTEGER64 int64_t
#define UNSIGNED64 uint64_t
#define REAL64 double
#define BIT1 uint8_t
#define BIT2 uint8_t
#define BIT3 uint8_t
#define BIT4 uint8_t
#define BIT5 uint8_t
#define BIT6 uint8_t
#define BIT7 uint8_t
#define BIT8 uint8_t

typedef union
{
   uint16 w;
   uint8 b[2];
} uint16union;

#define APPSTATE_IDLE      0x00
#define APPSTATE_INPUT     0x01
#define APPSTATE_OUTPUT    0x02

typedef struct
{
   BIT2 buttons;
   UNSIGNED32 heartbeat;
} __attribute__((packed)) _Rbuffer;

typedef struct
{
   BIT4 leds;
} __attribute__((packed)) _Wbuffer;

typedef struct
{
} __attribute__((packed)) _Cbuffer;

typedef struct
{
   uint8 state;                 // internal, don't change!!!!
} _App;

extern _Rbuffer Rb;
extern _Wbuffer Wb;
extern _Cbuffer Cb;
extern _App App;

#define EC_LITTLE_ENDIAN

#if !defined(EC_BIG_ENDIAN) && defined(EC_LITTLE_ENDIAN)

#define htoes(A) (A)
#define htoel(A) (A)
#define htoell(A) (A)
#define etohs(A) (A)
#define etohl(A) (A)
#define etohll(A) (A)

#elif !defined(EC_LITTLE_ENDIAN) && defined(EC_BIG_ENDIAN)

#define htoes(A) ((((uint16)(A) & 0xff00) >> 8) | \
                    (((uint16)(A) & 0x00ff) << 8))
#define htoel(A) ((((uint32)(A) & 0xff000000) >> 24) | \
                    (((uint32)(A) & 0x00ff0000) >> 8)  | \
                    (((uint32)(A) & 0x0000ff00) << 8)  | \
                    (((uint32)(A) & 0x000000ff) << 24))
#define htoell(A) ((((uint64)(A) & (uint64)0xff00000000000000ULL) >> 56) | \
                     (((uint64)(A) & (uint64)0x00ff000000000000ULL) >> 40) | \
                     (((uint64)(A) & (uint64)0x0000ff0000000000ULL) >> 24) | \
                     (((uint64)(A) & (uint64)0x000000ff00000000ULL) >> 8)  | \
                     (((uint64)(A) & (uint64)0x00000000ff000000ULL) << 8)  | \
                     (((uint64)(A) & (uint64)0x0000000000ff0000ULL) << 24) | \
                     (((uint64)(A) & (uint64)0x000000000000ff00ULL) << 40) | \
                     (((uint64)(A) & (uint64)0x00000000000000ffULL) << 56))

#define etohs  htoes
#define etohl  htoel
#define etohll htoell

#else

#error "Must define one of EC_BIG_ENDIAN or EC_LITTLE_ENDIAN"

#endif

#endif /* __UTYPES_H__ */
